==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridRowDragGhostContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridRowDragGhostContextDescription } from "./WebGridRowDragGhostContextDescription";
/**
 * @hidden
 */
var WebGridRowDragGhostContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridRowDragGhostContextDescriptionMetadata, _super);
    function WebGridRowDragGhostContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowDragGhostContextDescriptionMetadata.b = function (a) {
        if (WebGridRowDragGhostContextDescriptionMetadata.a == null) {
            WebGridRowDragGhostContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowDragGhostContextDescriptionMetadata.c(WebGridRowDragGhostContextDescriptionMetadata.a);
        }
        if (a.j(WebGridRowDragGhostContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridRowDragGhostContextDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridRowDragGhostContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowDragGhostContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("Data", "Unknown");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
    };
    WebGridRowDragGhostContextDescriptionMetadata.d = function (a) {
        WebGridRowDragGhostContextDescriptionMetadata.b(a);
        a.aa("WebGridRowDragGhostContext", function () { return new WebGridRowDragGhostContextDescription(); });
        a.z("WebGridRowDragGhostContext", WebGridRowDragGhostContextDescriptionMetadata.a);
    };
    WebGridRowDragGhostContextDescriptionMetadata.$t = markType(WebGridRowDragGhostContextDescriptionMetadata, 'WebGridRowDragGhostContextDescriptionMetadata');
    WebGridRowDragGhostContextDescriptionMetadata.a = null;
    return WebGridRowDragGhostContextDescriptionMetadata;
}(Base));
export { WebGridRowDragGhostContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridRowDragGhostContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebGridRowDragGhostContextDescription } from "./WebGridRowDragGhostContextDescription";
/**
 * @hidden
 */
var WebGridRowDragGhostContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridRowDragGhostContextDescriptionMetadata, _super);
    function WebGridRowDragGhostContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowDragGhostContextDescriptionMetadata.b = function (a) {
        if (WebGridRowDragGhostContextDescriptionMetadata.a == null) {
            WebGridRowDragGhostContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowDragGhostContextDescriptionMetadata.c(WebGridRowDragGhostContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowDragGhostContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridRowDragGhostContextDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridRowDragGhostContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowDragGhostContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "Unknown");
        a.item("Data", "Unknown");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
    };
    WebGridRowDragGhostContextDescriptionMetadata.d = function (a) {
        WebGridRowDragGhostContextDescriptionMetadata.b(a);
        a.ac("WebGridRowDragGhostContext", function () { return new WebGridRowDragGhostContextDescription(); });
        a.ab("WebGridRowDragGhostContext", WebGridRowDragGhostContextDescriptionMetadata.a);
    };
    WebGridRowDragGhostContextDescriptionMetadata.$t = markType(WebGridRowDragGhostContextDescriptionMetadata, 'WebGridRowDragGhostContextDescriptionMetadata');
    WebGridRowDragGhostContextDescriptionMetadata.a = null;
    return WebGridRowDragGhostContextDescriptionMetadata;
}(Base));
export { WebGridRowDragGhostContextDescriptionMetadata };
